# OPS06-BP01: Plan for unsuccessful changes

## Description

Có rollback plan cho mọi deployment.

## Implementation Guidance

- Document rollback procedures
- Test rollbacks regularly
- Database migration rollback plans
- Feature flag kill switches
- Communication plan for rollbacks

## Risk Level

High - Without rollback plans, failed deployments cause extended outages.
